@@ -286,11 +286,21 @@ class AFM:
 
         
 
-    def nanoscope_params(self):
+    def nanoscope_params(
+        self,
+        nanoscope_version = 6
+        ):
         '''
-        Function to extract relevant parameters from first Nanoscope file
+        Function to extract relevant parameters from first Nanoscope file.
+        By default the function will search for the parameters used in a
+        Nanoscope 6 file. If using Nanoscope 5, change the 'nanoscope_version'
+        input to 5.
         '''
 
+        if nanoscope_version not in [5, 6]:
+            Warning('The nanoscope_version input is not set to a compatible version (5 or 6)')
+            return
+
         filename = self.filelist[0]
         data = open(filename,"r")
 
@@ -299,40 +309,85 @@ class AFM:
             Warning('Input file not nanoscope')
             return
 
-        while data:
+        if nanoscope_version == 6:
 
-            line = data.readline().strip()
+            while data:
 
-            if line.startswith('\*File list end'):
-                break
+                line = data.readline().strip()
 
-            if len(line) < 1:
-                continue
-            
-            if re.search('\Data offset:', line):
-                _data_offset = [int(s) for s in line.split() if s.isdigit()]
+                if line.startswith('\*File list end'):
+                    break
 
-            elif re.search('\Data length:', line):
-                _data_length = [int(s) for s in line.split() if s.isdigit()]
-
-            elif re.search('\@4:Ramp size:', line):
-                _ramp_size = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
-
-            elif re.search('\Samps/line', line):
-                _samps_line = [int(s) for s in line.split() if s.isdigit()]
-
-            elif re.search('@Sens. Zsens:', line):
-                _zsens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
-
-            elif re.search('\@4:Z scale: V ', line):
-                _zscale = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
-
-            elif re.search('\@Sens. DeflSens:', line):
-                _def_sens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+                if len(line) < 1:
+                    continue
                 
-            elif re.search('\Spring Constant:', line):
-                _spr_const = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
-        data.close()
+                if re.search('\Data offset:', line):
+                    _data_offset = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('\Data length:', line):
+                    _data_length = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('\@4:Ramp size:', line):
+                    _ramp_size = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
+
+                elif re.search('\Samps/line', line):
+                    _samps_line = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('@Sens. Zsens:', line):
+                    _zsens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+
+                elif re.search('\@4:Z scale: V ', line):
+                    _zscale = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
+
+                elif re.search('\@Sens. DeflSens:', line):
+                    _def_sens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+                    
+                elif re.search('\Spring Constant:', line):
+                    try:
+                        _spr_const = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+                    except:
+                        _spr_const = re.findall(r'\d+',line)[0]
+            data.close()
+
+        elif nanoscope_version == 5:
+
+            while data:
+
+                line = data.readline().strip()
+
+                if line.startswith('\*File list end'):
+                    break
+
+                if len(line) < 1:
+                    continue
+                
+                if re.search('\Data offset:', line):
+                    _data_offset = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('\Data length:', line):
+                    _data_length = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('\@4:Ramp size:', line):
+                    _ramp_size = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
+
+                elif re.search('\Samps/line', line):
+                    _samps_line = [int(s) for s in line.split() if s.isdigit()]
+
+                elif re.search('\@Sens. Deflection:', line):
+                    _zsens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+
+                elif re.search('\@4:Z scale: V ', line):
+                    _zscale = re.findall(r'\d+',line)[1] + '.' + re.findall(r'\d+',line)[2]
+
+                elif re.search('\@Sens. Deflection:', line):
+                    _def_sens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+                    
+                elif re.search('\Spring Constant:', line):
+                    try:
+                        _spr_const = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
+                    except:
+                        _spr_const = re.findall(r'\d+',line)[0]
+            data.close()
 
         self.data_offset = int(_data_offset[0])
         self.data_length = int(_data_length[0])
